@@ -17,10 +17,10 @@ test_that("lsa", {
 })
 
 test_that("lsa input and output errors", {
-  expect_error(lsa(mod, par = "a,b,c"), regex = "invalid parameter") 
+  expect_error(lsa(mod, par = "a,b,c"), regex = "Invalid parameter") 
   expect_error(
     lsa(mod, par = "CL", var = "a,b,c"), 
-    regex = "invalid output name"
+    regex = "Invalid output name"
   ) 
   fun <- function(p, ...) {
     out <- mrgsim_df(mod)
@@ -29,7 +29,7 @@ test_that("lsa input and output errors", {
   }
   expect_error(
     lsa(mod, par = "CL", var = "CP", fun = fun), 
-    regex = "output from `fun` must contain"
+    regex = "Output from `fun` must contain"
   )
 })
 
